@@ -14,7 +14,7 @@ use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION     = version->new('0.2.1');
+our $VERSION = version->new('0.3.0');
 
 requires 'repos';
 requires 'verbose';
@@ -24,12 +24,17 @@ my $opt = Getopt::Alt->new(
     [ 'quote|q!', ]
 );
 
+sub sh_start {
+    $opt->process;
+
+    return;
+}
+
 sub sh {
     my ($self, $name) = @_;
     return unless -d $name;
 
     my $repo = $self->repos->{$name};
-    $opt->process if !%{ $opt->opt || {} };
 
     local $CWD = $name;
     my $cmd
@@ -55,7 +60,7 @@ Group::Git::Cmd::Sh - Runs shell script in each git project
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Sh version 0.2.1.
+This documentation refers to Group::Git::Cmd::Sh version 0.3.0.
 
 =head1 SYNOPSIS
 
